'''
--> ready for computing Baseline-vs-Trial pvalues into plotting and Excel
For conducting paired-t-test on
2. Bandpower features
extracted from CTA data
Designed for analyzing Flight Simulator data collected at CTA, Montreal in November 2021

Written by Mengting Zhao, on April 29 2022, updated on Sep 23 
'''

import numpy as np
import matplotlib.pyplot as plt
import mne
import os
from os.path import join as pjoin
import xlrd
import scipy.io as sio
# from xlwt import Workbook
from openpyxl import Workbook, load_workbook
import pandas as pd
from sklearn.discriminant_analysis import LinearDiscriminantAnalysis as LDA
from sklearn.model_selection import train_test_split
from sklearn.preprocessing import StandardScaler
from sklearn.preprocessing import MinMaxScaler
from sklearn.metrics import confusion_matrix
from sklearn.metrics import accuracy_score, classification_report
from sklearn import preprocessing
from sklearn import metrics
from utilis import get_root_path
import matplotlib.gridspec as gridspec
import math
import statsmodels.stats.multitest as smt
from scipy import stats
import itertools
from itertools import combinations
from utilis import create_info, ceil_decimal, comp_pvalues, pval_corrected, ax_barplot_annotate_brackets




## written by Mengting on April 29 2022, tested with success
def bandpower_condition_plot_comparison(m, bar_height, mat_org_1, mat_p_1, mat_org_2, mat_p_2, nb_condition=3, str_title='', str_x='', str_y='', dis=None):
    # bar_height = 1.9  #to be changed later
    w = 0.2
    # lis_color = ['green', 'orange']
    color_1 = (214, 187, 193)
    color_2 = (179, 106, 111)
    # Convert RGB values to the 0-1 range
    color_1_scaled = tuple([x / 255.0 for x in color_1])
    color_2_scaled = tuple([x / 255.0 for x in color_2])
    # lis_color = [(214, 187, 193), (179, 106, 111)]
    lis_color = [color_1_scaled,color_2_scaled]

    lis_w = [-0.1, 0.1]
    N = nb_condition  # N=4 or 3
    ind = np.arange(N)

    ax1 = plt.subplot(n_row, n_col, m)
    color_c = 'black'
    if nb_condition > 3:
        print('Baseline vs Trial comparison not supported')
    else:
        mat_contents_1 = mat_org_1
        # mat_contents_1 = mat_org_1*1000000*1000000  # for plotting in micro-volts
        mat_pvalues_1 = mat_p_1
        mat_contents_2 = mat_org_2
        # mat_contents_2 = mat_org_2*1000000*1000000  # for plotting in micro-volts
        mat_pvalues_2 = mat_p_2

    mean_fre_1 = np.mean(mat_contents_1, axis=0)
    std_fre_1 = np.std(mat_contents_1, axis=0)
    mean_fre_2 = np.mean(mat_contents_2, axis=0)
    std_fre_2 = np.std(mat_contents_2, axis=0)

    # ax1.set_ylabel(str_y, color=color_c)
    # ax1.tick_params(axis='y', labelcolor=color_c)
    ax1.set_ylabel(str_y, color=color_c, fontsize=18)
    ax1.tick_params(axis='y', labelcolor=color_c, labelsize=16)
    # plt.errorbar(ind, mean_fre, yerr=std_fre, color=color_c, fmt='none',marker='s', ms=6, mew=2, mfc=color_c, mec=color_c, capsize=8, capthick=1)

    # plt.errorbar(ind - 0.1, mean_fre_1, yerr=std_fre_1, color=lis_color[0], fmt='none', capsize=6, capthick=1, marker='s', ms=1)
    # plt.errorbar(ind + 0.1, mean_fre_2, yerr=std_fre_2, color=lis_color[1], fmt='none', capsize=6, capthick=1, marker='s', ms=1)
    ax1.errorbar(ind - 0.1, mean_fre_1, yerr=std_fre_1, color=lis_color[0], fmt='none', capsize=6, capthick=1, marker='s', ms=1)
    ax1.errorbar(ind + 0.1, mean_fre_2, yerr=std_fre_2, color=lis_color[1], fmt='none', capsize=6, capthick=1, marker='s', ms=1)
    # y_max = 1.5 * max(mean_fre_2[:] + std_fre_2[:])  # for alpha band comparison
    y_max = 1.3 * max(mean_fre_1[:] + std_fre_1[:])  # for theta band comparison
    # bar_height = y_max

    size_m = 20
    lis_pvals_two = []
    if nb_condition > 3:
        plt.xticks(ind, ('Rest', 'Training', 'Practice A', 'Practice B'), rotation=0)
    else:
        for i in range(nb_condition):
            anote_ind = np.asarray(lis_w) + i
            if i ==0:
                # plt.bar(ind[i]-0.1, mean_fre_1[i], width=w, color=lis_color[0], label='Baseline')
                # plt.bar(ind[i]+0.1, mean_fre_2[i], width=w,color=lis_color[1], label='Trial')
                ax1.bar(ind[i]-0.1, mean_fre_1[i], width=w, color=lis_color[0], label='Baseline')
                ax1.bar(ind[i]+0.1, mean_fre_2[i], width=w, color=lis_color[1], label='Trial')

            else:
                # plt.bar(ind[i]-0.1, mean_fre_1[i], width=w, color=lis_color[0])
                # plt.bar(ind[i]+0.1, mean_fre_2[i], width=w,color=lis_color[1])
                ax1.bar(ind[i]-0.1, mean_fre_1[i], width=w, color=lis_color[0])
                ax1.bar(ind[i]+0.1, mean_fre_2[i], width=w, color=lis_color[1])

            temp_mean = np.asarray([mean_fre_1[i], mean_fre_2[i]])
            temp_std = np.asarray([std_fre_1[i], std_fre_2[i]])

            matrix_temp = np.concatenate((mat_contents_1[:, i].reshape((-1, 1)), mat_contents_2[:, i].reshape((-1, 1))), axis=1)
            pvals_temp = comp_pvalues(matrix_temp)
            lis_pvals_two.append(pvals_temp)
            multi_barplot_annotate_brackets(bar_height, 0, 1, pvals_temp[0], anote_ind, temp_mean, temp_std)

        ax_barplot_annotate_brackets(ax1, 0, 1, mat_pvalues_1[0], ind-0.1, mean_fre_1, std_fre_1, dh=dis[0])
        ax_barplot_annotate_brackets(ax1, 0, 2, mat_pvalues_1[1], ind-0.1, mean_fre_1, std_fre_1, dh=dis[1])
        ax_barplot_annotate_brackets(ax1, 1, 2, mat_pvalues_1[2], ind-0.1, mean_fre_1, std_fre_1, dh=dis[2])
        ax_barplot_annotate_brackets(ax1, 0, 1, mat_pvalues_2[0], ind+0.1, mean_fre_2, std_fre_2, dh=dis[3])
        ax_barplot_annotate_brackets(ax1, 0, 2, mat_pvalues_2[1], ind+0.1, mean_fre_2, std_fre_2, dh=dis[4])
        ax_barplot_annotate_brackets(ax1, 1, 2, mat_pvalues_2[2], ind+0.1, mean_fre_2, std_fre_2, dh=dis[5])

        # plt.xticks(ind, ('Training', 'Practice A', 'Practice B'), rotation=0)
        # ax1.set_xticks(['Training', 'Practice A', 'Practice B'])
        ax1.set_ylim(top=1.05*y_max)
        ax1.set_title(str_title, fontsize=16)
        ax1.set_xticks(ind)
        ax1.set_xticklabels(['Training', 'Practice A', 'Practice B'], fontsize=16)

    
    lis_pvals_two = np.asarray(lis_pvals_two).flatten()
    return mean_fre_1, mean_fre_2, lis_pvals_two



############ the main function starts here##################################
data_dir = r'F:\FlightSim_experiment_2021\Concordia_preprocessed'
subjects = ['P01', 'P02', 'P03', 'P04', 'P05', 'P06', 'P07', 'P08', 'P09', 'P10',
            'P11', 'P12', 'P13', 'P14', 'P15', 'P16', 'P17', 'P18', 'P19', 'P20',
            'P21', 'P22', 'P23', 'P24']

loc_featurenames = ['_theta.xls', '_alpha.xls', '_lowBeta.xls', '_highBeta.xls', '_gamma.xls']
nb_features = len(loc_featurenames)

### for condition comparison without REST
conditions = ['training', 'practiceA', 'practiceB']
str_conditions = ['Training', 'PracticeA', 'PracticeB']

############# load the information of lobes (similar to Wenjun's)######################
names_areas = ['Frontal', 'Central', 'Temporal', 'Parietal', 'Occipital']
lis_frontal_l = [0, 1, 2, 3, 4, 5, 6, 9, 10]
lis_frontal_r = [33, 34, 35, 38, 39, 40, 41, 44, 45]
lis_central_l = [8, 11, 12, 13]
lis_central_r = [44, 48, 49, 50]
lis_temporal_l = [7, 14, 15, 16, 21]
lis_temporal_r = [42, 51, 52, 53, 58]
lis_parietal_l = [17, 18, 19, 20]
lis_parietal_r = [54, 55, 56, 57]
lis_occipital_l = [22, 24, 25, 26]
lis_occipital_r = [59, 61, 62, 63]
lis_areas = [lis_frontal_l, lis_frontal_r, lis_central_l, lis_central_r, lis_temporal_l,
             lis_temporal_r, lis_parietal_l, lis_parietal_r, lis_occipital_l, lis_occipital_r]
# # ## list the channel index for different AOI (area of interest), for theta band
idx_midfrontal = [37, 46, 47]

id_feature = 0  # for theta_bandpower feature
str_y = 'Theta band power'
# str_y = 'Theta band power ($\mu V^2$)'  #when plotted in micro-volts^2


# id_feature = 1
# str_y = 'Alpha band power'
# # str_y = 'Alpha band power ($\mu V^2$)'  #when plotted in micro-volts^2

# id_feature = 2
# str_y = 'Low-Beta band ($\mu V^2$)'

# id_feature = 3
# str_y = 'High-Beta band ($\mu V^2$)'

# id_feature = 4
# str_y = 'Gamma band'


n_chs = 64
# n = 3  # 3 difficulty levels
nb_trials = 22   # number of trials
nb_epo = np.zeros(nb_trials)

lis_training = [0, 1, 2, 3, 4, 5, 6]
lis_practice_a = [7, 8, 9, 10, 11, 12, 13, 14]
lis_practice_b = [15, 16, 17, 18, 19, 20, 21]
# #### including resting data
# lis_rest = [22, 23]

lis_activitites = [lis_training, lis_practice_a, lis_practice_b]

###############################first, deal with Baseline data ##################################################################
lis_features_bands = [[], [], [], [], [],
                      [], [], [], [], [], ]  ##to save the band powers for all brain areas (10)
matrix_all = []  # Baseline: the expected size is 24subjects*22trials (without averaging it's 24*64rows * 22 columns)
lis_features_bands_2 = [[], [], [], [], [],
                        [], [], [], [], [], ]  ##to save the band powers for all brain areas (10)
matrix_all_2 = []  #Trials: the expected size is 24subjects*22trials (without averaging it's 24*64rows * 22 columns)

for a_subject in subjects:
    ### for comparing Baseline bandpowers
    subject_path = data_dir + "\\" + a_subject + "\\" + r'baseline_features'
    res_fname = a_subject + '_baseline' + loc_featurenames[id_feature]
    data_fname = pjoin(subject_path, res_fname)
    wb = xlrd.open_workbook(data_fname)

    matrix_individual_1 = []  # the expected size is 64channels * 22trials (becomes 64*24 when including REST)
    # id_end = 0
    for id in range(nb_trials):
        id_sheet = id
        sheet = wb.sheet_by_index(id_sheet)  # replace id_sheet with (id_sheet+3) for l1-l3 tasks
        # v_s1 = sheet.col_values(0)
        n_col = sheet.row_len(rowx=0)
        nb_epo[id] = n_col
        tem = []
        for i in range(n_col): #there are n_col columns in total (nb of epochs)
            # allchn_values = sheet.cell_value(0, j)
            allchn = sheet.col_values(i)
            tem.append(allchn)
        ress = np.asarray(tem)
        ress.reshape([n_col, n_chs])
        mean_temp = np.mean(ress, axis=0).reshape((-1, 1))
        mean_temp = mean_temp*1000000*1000000  # convert to microvolts^2
        if len(matrix_individual_1) > 0:
            matrix_individual_1 = np.concatenate((matrix_individual_1, mean_temp), axis=1)
        else:
            matrix_individual_1 = mean_temp

    ####### ### for comparing Trial bandpowers ############################
    subject_path = data_dir + "\\" + a_subject + "\\" + r'features'
    res_fname = a_subject + loc_featurenames[id_feature]
    data_fname = pjoin(subject_path, res_fname)
    wb = xlrd.open_workbook(data_fname)
    matrix_individual_2 = []  # the expected size is 64channels * 22trials (becomes 64*24 when including REST)
    # id_end = 0
    for id in range(nb_trials):
        id_sheet = id
        sheet = wb.sheet_by_index(id_sheet)  # replace id_sheet with (id_sheet+3) for l1-l3 tasks
        # v_s1 = sheet.col_values(0)
        n_col = sheet.row_len(rowx=0)
        nb_epo[id] = n_col
        tem = []
        for i in range(n_col): #there are n_col columns in total (nb of epochs)
            # allchn_values = sheet.cell_value(0, j)
            allchn = sheet.col_values(i)
            tem.append(allchn)
        ress = np.asarray(tem)
        ress.reshape([n_col, n_chs])
        mean_temp = np.mean(ress, axis=0).reshape((-1, 1))  #until now, the results are in volts^2
        mean_temp = mean_temp*1000000*1000000  # convert to microvolts^2
        if len(matrix_individual_2) > 0:
            matrix_individual_2 = np.concatenate((matrix_individual_2, mean_temp), axis=1)
        else:
            matrix_individual_2 = mean_temp


    matrix_individual = np.concatenate((matrix_individual_1, matrix_individual_2), axis=1)

    ### added for Standarization ##################
    ##### the problem is that if we cannot do Standarization for Baseline and Trial separately
    # scaler = StandardScaler()
    scaler = MinMaxScaler()
    matrix_individual = scaler.fit_transform(matrix_individual)
    matrix_individual_1 = matrix_individual[:, 0:22]
    matrix_individual_2 = matrix_individual[:, 22:44]

    ###deal with Baseline features
    for idx_area in range(len(lis_areas)):
        ### each saved list is a 1*24trials matrix for one subject
        lis_features_bands[idx_area].append(np.mean(matrix_individual_1[lis_areas[idx_area], :], axis=0).reshape((1, -1)))
    ###########if don't averaging across channels, and do averaging afterwards
    if len(matrix_all) > 0:
        matrix_all = np.concatenate((matrix_all, matrix_individual_1), axis=0)
    else:
        matrix_all = matrix_individual_1

    ### deal with Trial features
    for idx_area in range(len(lis_areas)):
        ### each saved list is a 1*24trials matrix for one subject
        lis_features_bands_2[idx_area].append(np.mean(matrix_individual_2[lis_areas[idx_area], :], axis=0).reshape((1, -1)))

    ###########if don't averaging across channels, and do averaging afterwards
    if len(matrix_all_2) > 0:
        matrix_all_2 = np.concatenate((matrix_all_2, matrix_individual_2), axis=0)
    else:
        matrix_all_2 = matrix_individual_2

######## for each brain area, compute the condition-comparison (t-test) and plotting
pvals_areas = []  ### keeping the p-values computed for condition comparison under each area, 5 lists for 5 areas (each has 3 values)
id_matrix = np.arange(len(conditions))+1
for idx_area in range(5):  #combining the left&right for comparison
    temp_all = lis_features_bands[2*idx_area]
    temp_individual = []
    for id_subject in range(len(subjects)):
        if len(temp_individual)>0:
            temp_individual = np.concatenate((temp_individual, temp_all[id_subject]), axis=0)
        else:
            temp_individual = temp_all[id_subject]

    #### load the right-area and combine with the left one
    temp_all = lis_features_bands[2*idx_area+1]
    temp_individual_r = []
    for id_subject in range(len(subjects)):
        if len(temp_individual_r)>0:
            temp_individual_r = np.concatenate((temp_individual_r, temp_all[id_subject]), axis=0)
        else:
            temp_individual_r = temp_all[id_subject]

    temp_individual = np.concatenate((temp_individual, temp_individual_r), axis=0)  ##individual area (among the 5 areas)
    # temp = temp_individual[:, lis_rest]
    # mean_rest = np.mean(temp, axis=1).reshape((-1, 1))
    temp = temp_individual[:, lis_training]
    mean_train = np.mean(temp, axis=1).reshape((-1, 1))
    temp = temp_individual[:, lis_practice_a]
    mean_a = np.mean(temp, axis=1).reshape((-1, 1))
    temp = temp_individual[:, lis_practice_b]
    mean_b = np.mean(temp, axis=1).reshape((-1, 1))

    ##the version excluding REST condition
    mean_matrix = np.concatenate((mean_train, mean_a), axis=1)
    mean_matrix = np.concatenate((mean_matrix, mean_b), axis=1)

    mat_pvalues_tem = comp_pvalues(mean_matrix)
    mat_pvalues = pval_corrected(mat_pvalues_tem, method='bonferroni')
    mat_pvalues = ceil_decimal(np.round(mat_pvalues, decimals=4), 3)
    pvals_areas.append(mat_pvalues)


lis_mean = []  ##keeping the means for each condition: 3 lists for 3 conditions, each has 5 values for 5 areas
lis_std = []  ##keeping the std for each condition: 3 lists for 3 conditions, each has 5 values for 5 areas
lis_matrix = []  ##keeping the matrix on each condition for Trial-Baseline comparison: 3 lists for 3 conditions, each is a 48*5 matrix
for idx_activity in range(len(lis_activitites)):
    mean_matrix = []  ##a 48*5 matrix for each condition!!, 48=24subjects*2(L+R)
    for idx_area in range(5):  #combining the left&right for comparison
        temp_all = lis_features_bands[2*idx_area]
        temp_individual = []
        for id_subject in range(len(subjects)):
            if len(temp_individual)>0:
                temp_individual = np.concatenate((temp_individual, temp_all[id_subject]), axis=0)
            else:
                temp_individual = temp_all[id_subject]
        #### load the right-area and combine with the left one
        temp_all = lis_features_bands[2*idx_area+1]
        temp_individual_r = []
        for id_subject in range(len(subjects)):
            if len(temp_individual_r)>0:
                temp_individual_r = np.concatenate((temp_individual_r, temp_all[id_subject]), axis=0)
            else:
                temp_individual_r = temp_all[id_subject]

        temp_individual = np.concatenate((temp_individual, temp_individual_r), axis=0)  ## (24subjects*2(L+R))rows, cols=(22+2)trials
        temp = np.mean(temp_individual[:, lis_activitites[idx_activity]], axis=1).reshape((-1, 1))
        if len(mean_matrix):
            mean_matrix = np.concatenate((mean_matrix, temp), axis=1)
        else:
            mean_matrix = temp
    mean_fre = np.mean(mean_matrix, 0)
    std_fre = np.std(mean_matrix, 0)
    lis_mean.append(mean_fre)  #lis_mean contains 3 lists for 3 activitities, each contains the 5 values for 5 areas
    lis_std.append(std_fre)
    lis_matrix.append(mean_matrix)

###############################Second, deal with Trial data ##################################################################
######## for each brain area, compute the condition-comparison (t-test) and plotting
pvals_areas_2 = []  ### keeping the p-values computed for condition comparison under each area, 5 lists for 5 areas (each has 3 values)
id_matrix = np.arange(len(conditions))+1
for idx_area in range(5):  #combining the left&right for comparison
    temp_all = lis_features_bands_2[2*idx_area]
    temp_individual = []
    for id_subject in range(len(subjects)):
        if len(temp_individual)>0:
            temp_individual = np.concatenate((temp_individual, temp_all[id_subject]), axis=0)
        else:
            temp_individual = temp_all[id_subject]

    #### load the right-area and combine with the left one
    temp_all = lis_features_bands_2[2*idx_area+1]
    temp_individual_r = []
    for id_subject in range(len(subjects)):
        if len(temp_individual_r)>0:
            temp_individual_r = np.concatenate((temp_individual_r, temp_all[id_subject]), axis=0)
        else:
            temp_individual_r = temp_all[id_subject]

    # temp_individual = np.concatenate((temp_individual, temp_individual_r), axis=0)  ##individual area (among the 5 areas)
    # temp = temp_individual[:, lis_rest]
    # mean_rest = np.mean(temp, axis=1).reshape((-1, 1))
    temp = temp_individual[:, lis_training]
    mean_train = np.mean(temp, axis=1).reshape((-1, 1))
    temp = temp_individual[:, lis_practice_a]
    mean_a = np.mean(temp, axis=1).reshape((-1, 1))
    temp = temp_individual[:, lis_practice_b]
    mean_b = np.mean(temp, axis=1).reshape((-1, 1))

    ##the version excluding REST condition
    mean_matrix = np.concatenate((mean_train, mean_a), axis=1)
    mean_matrix = np.concatenate((mean_matrix, mean_b), axis=1)

    mat_pvalues_tem = comp_pvalues(mean_matrix)
    mat_pvalues = pval_corrected(mat_pvalues_tem, method='bonferroni')
    mat_pvalues = ceil_decimal(np.round(mat_pvalues, decimals=4), 3)
    pvals_areas_2.append(mat_pvalues)


lis_mean_2 = []  ##keeping the means for each condition: 3 lists for 3 conditions, each has 5 values for 5 areas
lis_std_2 = []  ##keeping the std for each condition: 3 lists for 3 conditions, each has 5 values for 5 areas
lis_matrix_2 = []  ##keeping the matrix on each condition for Trial-Baseline comparison: 3 lists for 3 conditions, each is a 48*5 matrix
for idx_activity in range(len(lis_activitites)):
    mean_matrix = []  ##a 48*5 matrix for each condition!!, 48=24subjects*2(L+R)
    for idx_area in range(5):  #combining the left&right for comparison
        temp_all = lis_features_bands_2[2*idx_area]
        temp_individual = []
        for id_subject in range(len(subjects)):
            if len(temp_individual)>0:
                temp_individual = np.concatenate((temp_individual, temp_all[id_subject]), axis=0)
            else:
                temp_individual = temp_all[id_subject]
        #### load the right-area and combine with the left one
        temp_all = lis_features_bands_2[2*idx_area+1]
        temp_individual_r = []
        for id_subject in range(len(subjects)):
            if len(temp_individual_r)>0:
                temp_individual_r = np.concatenate((temp_individual_r, temp_all[id_subject]), axis=0)
            else:
                temp_individual_r = temp_all[id_subject]

        temp_individual = np.concatenate((temp_individual, temp_individual_r), axis=0)  ## (24subjects*2(L+R))rows, cols=(22+2)trials
        temp = np.mean(temp_individual[:, lis_activitites[idx_activity]], axis=1).reshape((-1, 1))
        if len(mean_matrix):
            mean_matrix = np.concatenate((mean_matrix, temp), axis=1)
        else:
            mean_matrix = temp
    mean_fre = np.mean(mean_matrix, 0)
    std_fre = np.std(mean_matrix, 0)
    lis_mean_2.append(mean_fre)  #lis_mean contains 3 lists for 3 activitities, each contains the 5 values for 5 areas
    lis_std_2.append(std_fre)
    lis_matrix_2.append(mean_matrix)

###################### integrating the pvals results to the area-wise plottings
############ plot the results for each area with multiple bars
n_conditions = len(conditions)
lis_linestyles = ['solid', 'dashed', 'dashdot']
lis_colors = ['green', 'orange', 'blue']
y_label = ''
str_x = 'Training stages'
n_row = 2
n_col = int(math.ceil(5/n_row))
lis_bar = [1, 1, 1, 1, 1]  # used to control the position of *** when plotting pvals
p_fname = 'parameters_pvals.xlsx'
wb = Workbook()

id_matrix = np.arange(5)+1  #plotting along the 5 brain areas (x-label)
plt.figure(figsize=(19.2, 9.6))
# lis_w = [-0.3, -0.1, 0.1, 0.3]  #used together with 4-condition version
lis_w = [-0.2, 0, 0.2]
w = 0.2


bar_height = [0.57, 0.23, 0.5, 0.177, 0.72]  

### for theta band comparison
dis_loc = [[0, 2, 0, 0, 0, 0],
           [1, 5, 2, 1, 5, 5],
           [1, 5, 0, 1, 5, 5],
           [16.5, 5, 0, 5, 5, 5],
           [10, 10, 15, 2, 8, 5]]


res_matrix = []
res_matrix_2 = []
lisp_between = []  ## used to save the p-values between trial and baseline under each area (5 areas in total)
for idx_area in range(5):
    pp = np.asarray(lis_matrix[0][:, idx_area]).reshape((-1, 1))
    pp2 = np.asarray(lis_matrix[1][:, idx_area]).reshape((-1, 1))
    pp3 = np.asarray(lis_matrix[2][:, idx_area]).reshape((-1, 1))
    mat_contents_1 = np.concatenate((pp, pp2), axis=1)
    mat_contents_1 = np.concatenate((mat_contents_1, pp3), axis=1)
    mat_pvalues_1 = pvals_areas[idx_area]

    pp = np.asarray(lis_matrix_2[0][:, idx_area]).reshape((-1, 1))
    pp2 = np.asarray(lis_matrix_2[1][:, idx_area]).reshape((-1, 1))
    pp3 = np.asarray(lis_matrix_2[2][:, idx_area]).reshape((-1, 1))
    mat_contents_2 = np.concatenate((pp, pp2), axis=1)
    mat_contents_2 = np.concatenate((mat_contents_2, pp3), axis=1)
    mat_pvalues_2 = pvals_areas_2[idx_area]
    print(000)
    row = int(np.floor(idx_area/n_col))
    col = int(idx_area - n_col*row)
    mean_fre_1, mean_fre_2, pval_trialbase = bandpower_condition_plot_comparison(idx_area+1, bar_height[idx_area], mat_contents_1, mat_pvalues_1, mat_contents_2, mat_pvalues_2, n_conditions, names_areas[idx_area], str_x, str_y, dis_loc[idx_area])

    lisp_between.append(pval_trialbase)
    res_matrix.append(mean_fre_1)
    res_matrix_2.append(mean_fre_2)

    plt.subplots_adjust(hspace=0.4, wspace=0.4)
    # plt.show()

plt.legend(bbox_to_anchor=(1.05, 1), borderaxespad=0)
plt.show()
